netapp_ontap.models.igroup_connectivity_tracking API documentation
Description: Copyright &copy; 2026 NetApp Inc. All rights reserved …

# Module `netapp_ontap.models.igroup_connectivity_tracking`

Copyright © 2026 NetApp Inc. All rights reserved.

This file has been automatically generated based on the ONTAP REST API documentation.

## Classes

`class IgroupConnectivityTrackingSchema (*, only: types.StrSequenceOrSet | None = None, exclude: types.StrSequenceOrSet = (), many: bool | None = None, context: dict | None = None, load_only: types.StrSequenceOrSet = (), dump_only: types.StrSequenceOrSet = (), partial: bool | types.StrSequenceOrSet | None = None, unknown: str | None = None)`

  The fields of the IgroupConnectivityTracking object

  ### Ancestors

  - netapp_ontap.resource.ResourceSchema
  - marshmallow.schema.Schema
  - marshmallow.base.SchemaABC
  - abc.ABC

  ### Class variables

  `alerts: List[IgroupConnectivityTrackingAlerts] GET`

    The alerts field of the igroup_connectivity_tracking.

  `connection_state: str GET`

    Connection state.

    Valid choices:

    - full
    - none
    - partial
    - no_initiators
    - no_lun_maps
  `required_nodes: List[ClusterNodesHaPartners] GET`

    Nodes to which the initiators in this group should be connected to ensure reliable service. This is the collection of any node hosting a LUN mapped to this igroup as well as the HA partners of those nodes.